# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities

__all__ = [
    'GetOrchestratorResult',
    'AwaitableGetOrchestratorResult',
    'get_orchestrator',
    'get_orchestrator_output',
]

@pulumi.output_type
class GetOrchestratorResult:
    """
    A collection of values returned by getOrchestrator.
    """
    def __init__(__self__, cluster_endpoint=None, id=None, k8s_connector_id=None, name=None, region=None):
        if cluster_endpoint and not isinstance(cluster_endpoint, str):
            raise TypeError("Expected argument 'cluster_endpoint' to be a str")
        pulumi.set(__self__, "cluster_endpoint", cluster_endpoint)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if k8s_connector_id and not isinstance(k8s_connector_id, str):
            raise TypeError("Expected argument 'k8s_connector_id' to be a str")
        pulumi.set(__self__, "k8s_connector_id", k8s_connector_id)
        if name and not isinstance(name, str):
            raise TypeError("Expected argument 'name' to be a str")
        pulumi.set(__self__, "name", name)
        if region and not isinstance(region, str):
            raise TypeError("Expected argument 'region' to be a str")
        pulumi.set(__self__, "region", region)

    @_builtins.property
    @pulumi.getter(name="clusterEndpoint")
    def cluster_endpoint(self) -> _builtins.str:
        """
        Endpoint of the k8s cluster being onboarded under the orchestrator
        """
        return pulumi.get(self, "cluster_endpoint")

    @_builtins.property
    @pulumi.getter
    def id(self) -> _builtins.str:
        """
        The provider-assigned unique ID for this managed resource.
        """
        return pulumi.get(self, "id")

    @_builtins.property
    @pulumi.getter(name="k8sConnectorId")
    def k8s_connector_id(self) -> Optional[_builtins.str]:
        """
        ID of the Harness Kubernetes Connector Being used
        """
        return pulumi.get(self, "k8s_connector_id")

    @_builtins.property
    @pulumi.getter
    def name(self) -> _builtins.str:
        """
        Name of the Orchestrator
        """
        return pulumi.get(self, "name")

    @_builtins.property
    @pulumi.getter
    def region(self) -> Optional[_builtins.str]:
        """
        Region of the k8s cluster
        """
        return pulumi.get(self, "region")


class AwaitableGetOrchestratorResult(GetOrchestratorResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetOrchestratorResult(
            cluster_endpoint=self.cluster_endpoint,
            id=self.id,
            k8s_connector_id=self.k8s_connector_id,
            name=self.name,
            region=self.region)


def get_orchestrator(cluster_endpoint: Optional[_builtins.str] = None,
                     k8s_connector_id: Optional[_builtins.str] = None,
                     name: Optional[_builtins.str] = None,
                     region: Optional[_builtins.str] = None,
                     opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetOrchestratorResult:
    """
    Data source for retrieving a Harness ClusterOrchestrator.

    ## Example Usage


    :param _builtins.str cluster_endpoint: Endpoint of the k8s cluster being onboarded under the orchestrator
    :param _builtins.str k8s_connector_id: ID of the Harness Kubernetes Connector Being used
    :param _builtins.str name: Name of the Orchestrator
    :param _builtins.str region: Region of the k8s cluster
    """
    __args__ = dict()
    __args__['clusterEndpoint'] = cluster_endpoint
    __args__['k8sConnectorId'] = k8s_connector_id
    __args__['name'] = name
    __args__['region'] = region
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('harness:cluster/getOrchestrator:getOrchestrator', __args__, opts=opts, typ=GetOrchestratorResult).value

    return AwaitableGetOrchestratorResult(
        cluster_endpoint=pulumi.get(__ret__, 'cluster_endpoint'),
        id=pulumi.get(__ret__, 'id'),
        k8s_connector_id=pulumi.get(__ret__, 'k8s_connector_id'),
        name=pulumi.get(__ret__, 'name'),
        region=pulumi.get(__ret__, 'region'))
def get_orchestrator_output(cluster_endpoint: Optional[pulumi.Input[_builtins.str]] = None,
                            k8s_connector_id: Optional[pulumi.Input[Optional[_builtins.str]]] = None,
                            name: Optional[pulumi.Input[_builtins.str]] = None,
                            region: Optional[pulumi.Input[Optional[_builtins.str]]] = None,
                            opts: Optional[Union[pulumi.InvokeOptions, pulumi.InvokeOutputOptions]] = None) -> pulumi.Output[GetOrchestratorResult]:
    """
    Data source for retrieving a Harness ClusterOrchestrator.

    ## Example Usage


    :param _builtins.str cluster_endpoint: Endpoint of the k8s cluster being onboarded under the orchestrator
    :param _builtins.str k8s_connector_id: ID of the Harness Kubernetes Connector Being used
    :param _builtins.str name: Name of the Orchestrator
    :param _builtins.str region: Region of the k8s cluster
    """
    __args__ = dict()
    __args__['clusterEndpoint'] = cluster_endpoint
    __args__['k8sConnectorId'] = k8s_connector_id
    __args__['name'] = name
    __args__['region'] = region
    opts = pulumi.InvokeOutputOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke_output('harness:cluster/getOrchestrator:getOrchestrator', __args__, opts=opts, typ=GetOrchestratorResult)
    return __ret__.apply(lambda __response__: GetOrchestratorResult(
        cluster_endpoint=pulumi.get(__response__, 'cluster_endpoint'),
        id=pulumi.get(__response__, 'id'),
        k8s_connector_id=pulumi.get(__response__, 'k8s_connector_id'),
        name=pulumi.get(__response__, 'name'),
        region=pulumi.get(__response__, 'region')))



# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from . import _utilities

__all__ = ['ApplicationGitSyncArgs', 'ApplicationGitSync']

@pulumi.input_type
class ApplicationGitSyncArgs:
    def __init__(__self__, *,
                 app_id: pulumi.Input[_builtins.str],
                 branch: pulumi.Input[_builtins.str],
                 connector_id: pulumi.Input[_builtins.str],
                 enabled: Optional[pulumi.Input[_builtins.bool]] = None,
                 repository_name: Optional[pulumi.Input[_builtins.str]] = None):
        """
        The set of arguments for constructing a ApplicationGitSync resource.
        :param pulumi.Input[_builtins.str] app_id: The id of the application.
        :param pulumi.Input[_builtins.str] branch: The branch of the git repository to sync to.
        :param pulumi.Input[_builtins.str] connector_id: The id of the git connector to use.
        :param pulumi.Input[_builtins.bool] enabled: Whether or not to enable git sync.
        :param pulumi.Input[_builtins.str] repository_name: The name of the git repository to sync to. This is only used if the git connector is for an account and not an individual repository.
        """
        pulumi.set(__self__, "app_id", app_id)
        pulumi.set(__self__, "branch", branch)
        pulumi.set(__self__, "connector_id", connector_id)
        if enabled is not None:
            pulumi.set(__self__, "enabled", enabled)
        if repository_name is not None:
            pulumi.set(__self__, "repository_name", repository_name)

    @_builtins.property
    @pulumi.getter(name="appId")
    def app_id(self) -> pulumi.Input[_builtins.str]:
        """
        The id of the application.
        """
        return pulumi.get(self, "app_id")

    @app_id.setter
    def app_id(self, value: pulumi.Input[_builtins.str]):
        pulumi.set(self, "app_id", value)

    @_builtins.property
    @pulumi.getter
    def branch(self) -> pulumi.Input[_builtins.str]:
        """
        The branch of the git repository to sync to.
        """
        return pulumi.get(self, "branch")

    @branch.setter
    def branch(self, value: pulumi.Input[_builtins.str]):
        pulumi.set(self, "branch", value)

    @_builtins.property
    @pulumi.getter(name="connectorId")
    def connector_id(self) -> pulumi.Input[_builtins.str]:
        """
        The id of the git connector to use.
        """
        return pulumi.get(self, "connector_id")

    @connector_id.setter
    def connector_id(self, value: pulumi.Input[_builtins.str]):
        pulumi.set(self, "connector_id", value)

    @_builtins.property
    @pulumi.getter
    def enabled(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        Whether or not to enable git sync.
        """
        return pulumi.get(self, "enabled")

    @enabled.setter
    def enabled(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "enabled", value)

    @_builtins.property
    @pulumi.getter(name="repositoryName")
    def repository_name(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The name of the git repository to sync to. This is only used if the git connector is for an account and not an individual repository.
        """
        return pulumi.get(self, "repository_name")

    @repository_name.setter
    def repository_name(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "repository_name", value)


@pulumi.input_type
class _ApplicationGitSyncState:
    def __init__(__self__, *,
                 app_id: Optional[pulumi.Input[_builtins.str]] = None,
                 branch: Optional[pulumi.Input[_builtins.str]] = None,
                 connector_id: Optional[pulumi.Input[_builtins.str]] = None,
                 enabled: Optional[pulumi.Input[_builtins.bool]] = None,
                 repository_name: Optional[pulumi.Input[_builtins.str]] = None):
        """
        Input properties used for looking up and filtering ApplicationGitSync resources.
        :param pulumi.Input[_builtins.str] app_id: The id of the application.
        :param pulumi.Input[_builtins.str] branch: The branch of the git repository to sync to.
        :param pulumi.Input[_builtins.str] connector_id: The id of the git connector to use.
        :param pulumi.Input[_builtins.bool] enabled: Whether or not to enable git sync.
        :param pulumi.Input[_builtins.str] repository_name: The name of the git repository to sync to. This is only used if the git connector is for an account and not an individual repository.
        """
        if app_id is not None:
            pulumi.set(__self__, "app_id", app_id)
        if branch is not None:
            pulumi.set(__self__, "branch", branch)
        if connector_id is not None:
            pulumi.set(__self__, "connector_id", connector_id)
        if enabled is not None:
            pulumi.set(__self__, "enabled", enabled)
        if repository_name is not None:
            pulumi.set(__self__, "repository_name", repository_name)

    @_builtins.property
    @pulumi.getter(name="appId")
    def app_id(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The id of the application.
        """
        return pulumi.get(self, "app_id")

    @app_id.setter
    def app_id(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "app_id", value)

    @_builtins.property
    @pulumi.getter
    def branch(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The branch of the git repository to sync to.
        """
        return pulumi.get(self, "branch")

    @branch.setter
    def branch(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "branch", value)

    @_builtins.property
    @pulumi.getter(name="connectorId")
    def connector_id(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The id of the git connector to use.
        """
        return pulumi.get(self, "connector_id")

    @connector_id.setter
    def connector_id(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "connector_id", value)

    @_builtins.property
    @pulumi.getter
    def enabled(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        Whether or not to enable git sync.
        """
        return pulumi.get(self, "enabled")

    @enabled.setter
    def enabled(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "enabled", value)

    @_builtins.property
    @pulumi.getter(name="repositoryName")
    def repository_name(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The name of the git repository to sync to. This is only used if the git connector is for an account and not an individual repository.
        """
        return pulumi.get(self, "repository_name")

    @repository_name.setter
    def repository_name(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "repository_name", value)


@pulumi.type_token("harness:index/applicationGitSync:ApplicationGitSync")
class ApplicationGitSync(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 app_id: Optional[pulumi.Input[_builtins.str]] = None,
                 branch: Optional[pulumi.Input[_builtins.str]] = None,
                 connector_id: Optional[pulumi.Input[_builtins.str]] = None,
                 enabled: Optional[pulumi.Input[_builtins.bool]] = None,
                 repository_name: Optional[pulumi.Input[_builtins.str]] = None,
                 __props__=None):
        """
        Resource for configuring application git sync.

        ## Example Usage

        ```python
        import pulumi
        import pulumi_harness as harness

        default = harness.get_secret_manager(default=True)
        github_token = harness.EncryptedText("github_token",
            name="github_token",
            value="<TOKEN>",
            secret_manager_id=default.id)
        myrepo = harness.GitConnector("myrepo",
            name="myrepo",
            url="https://github.com/someorg/myrepo",
            branch="main",
            generate_webhook_url=True,
            username="someuser",
            password_secret_id=github_token.id,
            url_type="REPO")
        example = harness.Application("example", name="example-app")
        example_application_git_sync = harness.ApplicationGitSync("example",
            app_id=example.id,
            connector_id=myrepo.id,
            branch="main",
            enabled=False)
        ```

        ## Import

        The `pulumi import` command can be used, for example:

        Import using the Harness application id

        ```sh
        $ pulumi import harness:index/applicationGitSync:ApplicationGitSync myapp Xyz123
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[_builtins.str] app_id: The id of the application.
        :param pulumi.Input[_builtins.str] branch: The branch of the git repository to sync to.
        :param pulumi.Input[_builtins.str] connector_id: The id of the git connector to use.
        :param pulumi.Input[_builtins.bool] enabled: Whether or not to enable git sync.
        :param pulumi.Input[_builtins.str] repository_name: The name of the git repository to sync to. This is only used if the git connector is for an account and not an individual repository.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: ApplicationGitSyncArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        Resource for configuring application git sync.

        ## Example Usage

        ```python
        import pulumi
        import pulumi_harness as harness

        default = harness.get_secret_manager(default=True)
        github_token = harness.EncryptedText("github_token",
            name="github_token",
            value="<TOKEN>",
            secret_manager_id=default.id)
        myrepo = harness.GitConnector("myrepo",
            name="myrepo",
            url="https://github.com/someorg/myrepo",
            branch="main",
            generate_webhook_url=True,
            username="someuser",
            password_secret_id=github_token.id,
            url_type="REPO")
        example = harness.Application("example", name="example-app")
        example_application_git_sync = harness.ApplicationGitSync("example",
            app_id=example.id,
            connector_id=myrepo.id,
            branch="main",
            enabled=False)
        ```

        ## Import

        The `pulumi import` command can be used, for example:

        Import using the Harness application id

        ```sh
        $ pulumi import harness:index/applicationGitSync:ApplicationGitSync myapp Xyz123
        ```

        :param str resource_name: The name of the resource.
        :param ApplicationGitSyncArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(ApplicationGitSyncArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 app_id: Optional[pulumi.Input[_builtins.str]] = None,
                 branch: Optional[pulumi.Input[_builtins.str]] = None,
                 connector_id: Optional[pulumi.Input[_builtins.str]] = None,
                 enabled: Optional[pulumi.Input[_builtins.bool]] = None,
                 repository_name: Optional[pulumi.Input[_builtins.str]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = ApplicationGitSyncArgs.__new__(ApplicationGitSyncArgs)

            if app_id is None and not opts.urn:
                raise TypeError("Missing required property 'app_id'")
            __props__.__dict__["app_id"] = app_id
            if branch is None and not opts.urn:
                raise TypeError("Missing required property 'branch'")
            __props__.__dict__["branch"] = branch
            if connector_id is None and not opts.urn:
                raise TypeError("Missing required property 'connector_id'")
            __props__.__dict__["connector_id"] = connector_id
            __props__.__dict__["enabled"] = enabled
            __props__.__dict__["repository_name"] = repository_name
        super(ApplicationGitSync, __self__).__init__(
            'harness:index/applicationGitSync:ApplicationGitSync',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            app_id: Optional[pulumi.Input[_builtins.str]] = None,
            branch: Optional[pulumi.Input[_builtins.str]] = None,
            connector_id: Optional[pulumi.Input[_builtins.str]] = None,
            enabled: Optional[pulumi.Input[_builtins.bool]] = None,
            repository_name: Optional[pulumi.Input[_builtins.str]] = None) -> 'ApplicationGitSync':
        """
        Get an existing ApplicationGitSync resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[_builtins.str] app_id: The id of the application.
        :param pulumi.Input[_builtins.str] branch: The branch of the git repository to sync to.
        :param pulumi.Input[_builtins.str] connector_id: The id of the git connector to use.
        :param pulumi.Input[_builtins.bool] enabled: Whether or not to enable git sync.
        :param pulumi.Input[_builtins.str] repository_name: The name of the git repository to sync to. This is only used if the git connector is for an account and not an individual repository.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _ApplicationGitSyncState.__new__(_ApplicationGitSyncState)

        __props__.__dict__["app_id"] = app_id
        __props__.__dict__["branch"] = branch
        __props__.__dict__["connector_id"] = connector_id
        __props__.__dict__["enabled"] = enabled
        __props__.__dict__["repository_name"] = repository_name
        return ApplicationGitSync(resource_name, opts=opts, __props__=__props__)

    @_builtins.property
    @pulumi.getter(name="appId")
    def app_id(self) -> pulumi.Output[_builtins.str]:
        """
        The id of the application.
        """
        return pulumi.get(self, "app_id")

    @_builtins.property
    @pulumi.getter
    def branch(self) -> pulumi.Output[_builtins.str]:
        """
        The branch of the git repository to sync to.
        """
        return pulumi.get(self, "branch")

    @_builtins.property
    @pulumi.getter(name="connectorId")
    def connector_id(self) -> pulumi.Output[_builtins.str]:
        """
        The id of the git connector to use.
        """
        return pulumi.get(self, "connector_id")

    @_builtins.property
    @pulumi.getter
    def enabled(self) -> pulumi.Output[Optional[_builtins.bool]]:
        """
        Whether or not to enable git sync.
        """
        return pulumi.get(self, "enabled")

    @_builtins.property
    @pulumi.getter(name="repositoryName")
    def repository_name(self) -> pulumi.Output[Optional[_builtins.str]]:
        """
        The name of the git repository to sync to. This is only used if the git connector is for an account and not an individual repository.
        """
        return pulumi.get(self, "repository_name")




# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities
from . import outputs

__all__ = [
    'GetDbSchemaResult',
    'AwaitableGetDbSchemaResult',
    'get_db_schema',
    'get_db_schema_output',
]

@pulumi.output_type
class GetDbSchemaResult:
    """
    A collection of values returned by getDbSchema.
    """
    def __init__(__self__, changelog_script=None, description=None, id=None, identifier=None, migration_type=None, name=None, org_id=None, project_id=None, schema_sources=None, service=None, tags=None, type=None):
        if changelog_script and not isinstance(changelog_script, dict):
            raise TypeError("Expected argument 'changelog_script' to be a dict")
        pulumi.set(__self__, "changelog_script", changelog_script)
        if description and not isinstance(description, str):
            raise TypeError("Expected argument 'description' to be a str")
        pulumi.set(__self__, "description", description)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if identifier and not isinstance(identifier, str):
            raise TypeError("Expected argument 'identifier' to be a str")
        pulumi.set(__self__, "identifier", identifier)
        if migration_type and not isinstance(migration_type, str):
            raise TypeError("Expected argument 'migration_type' to be a str")
        pulumi.set(__self__, "migration_type", migration_type)
        if name and not isinstance(name, str):
            raise TypeError("Expected argument 'name' to be a str")
        pulumi.set(__self__, "name", name)
        if org_id and not isinstance(org_id, str):
            raise TypeError("Expected argument 'org_id' to be a str")
        pulumi.set(__self__, "org_id", org_id)
        if project_id and not isinstance(project_id, str):
            raise TypeError("Expected argument 'project_id' to be a str")
        pulumi.set(__self__, "project_id", project_id)
        if schema_sources and not isinstance(schema_sources, list):
            raise TypeError("Expected argument 'schema_sources' to be a list")
        pulumi.set(__self__, "schema_sources", schema_sources)
        if service and not isinstance(service, str):
            raise TypeError("Expected argument 'service' to be a str")
        pulumi.set(__self__, "service", service)
        if tags and not isinstance(tags, list):
            raise TypeError("Expected argument 'tags' to be a list")
        pulumi.set(__self__, "tags", tags)
        if type and not isinstance(type, str):
            raise TypeError("Expected argument 'type' to be a str")
        pulumi.set(__self__, "type", type)

    @_builtins.property
    @pulumi.getter(name="changelogScript")
    def changelog_script(self) -> 'outputs.GetDbSchemaChangelogScriptResult':
        """
        Configuration to clone changeSets using script
        """
        return pulumi.get(self, "changelog_script")

    @_builtins.property
    @pulumi.getter
    def description(self) -> _builtins.str:
        """
        Description of the resource.
        """
        return pulumi.get(self, "description")

    @_builtins.property
    @pulumi.getter
    def id(self) -> _builtins.str:
        """
        The provider-assigned unique ID for this managed resource.
        """
        return pulumi.get(self, "id")

    @_builtins.property
    @pulumi.getter
    def identifier(self) -> _builtins.str:
        """
        Unique identifier of the resource.
        """
        return pulumi.get(self, "identifier")

    @_builtins.property
    @pulumi.getter(name="migrationType")
    def migration_type(self) -> Optional[_builtins.str]:
        """
        DB Migration tool type. Valid values are: Liquibase, Flyway
        """
        return pulumi.get(self, "migration_type")

    @_builtins.property
    @pulumi.getter
    def name(self) -> Optional[_builtins.str]:
        """
        Name of the resource.
        """
        return pulumi.get(self, "name")

    @_builtins.property
    @pulumi.getter(name="orgId")
    def org_id(self) -> _builtins.str:
        """
        Unique identifier of the organization.
        """
        return pulumi.get(self, "org_id")

    @_builtins.property
    @pulumi.getter(name="projectId")
    def project_id(self) -> _builtins.str:
        """
        Unique identifier of the project.
        """
        return pulumi.get(self, "project_id")

    @_builtins.property
    @pulumi.getter(name="schemaSources")
    def schema_sources(self) -> Sequence['outputs.GetDbSchemaSchemaSourceResult']:
        """
        Provides a connector and path at which to find the database schema representation
        """
        return pulumi.get(self, "schema_sources")

    @_builtins.property
    @pulumi.getter
    def service(self) -> _builtins.str:
        """
        The service associated with schema
        """
        return pulumi.get(self, "service")

    @_builtins.property
    @pulumi.getter
    def tags(self) -> Sequence[_builtins.str]:
        """
        Tags to associate with the resource.
        """
        return pulumi.get(self, "tags")

    @_builtins.property
    @pulumi.getter
    def type(self) -> Optional[_builtins.str]:
        """
        Type of the database schema. Valid values are: Repository, Script
        """
        return pulumi.get(self, "type")


class AwaitableGetDbSchemaResult(GetDbSchemaResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetDbSchemaResult(
            changelog_script=self.changelog_script,
            description=self.description,
            id=self.id,
            identifier=self.identifier,
            migration_type=self.migration_type,
            name=self.name,
            org_id=self.org_id,
            project_id=self.project_id,
            schema_sources=self.schema_sources,
            service=self.service,
            tags=self.tags,
            type=self.type)


def get_db_schema(identifier: Optional[_builtins.str] = None,
                  migration_type: Optional[_builtins.str] = None,
                  name: Optional[_builtins.str] = None,
                  org_id: Optional[_builtins.str] = None,
                  project_id: Optional[_builtins.str] = None,
                  type: Optional[_builtins.str] = None,
                  opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetDbSchemaResult:
    """
    Data source for retrieving a Harness DBDevOps Schema.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_harness as harness

    example = harness.platform.get_db_schema(identifier="identifier",
        org_id="org_id",
        project_id="project_id")
    ```


    :param _builtins.str identifier: Unique identifier of the resource.
    :param _builtins.str migration_type: DB Migration tool type. Valid values are: Liquibase, Flyway
    :param _builtins.str name: Name of the resource.
    :param _builtins.str org_id: Unique identifier of the organization.
    :param _builtins.str project_id: Unique identifier of the project.
    :param _builtins.str type: Type of the database schema. Valid values are: Repository, Script
    """
    __args__ = dict()
    __args__['identifier'] = identifier
    __args__['migrationType'] = migration_type
    __args__['name'] = name
    __args__['orgId'] = org_id
    __args__['projectId'] = project_id
    __args__['type'] = type
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('harness:platform/getDbSchema:getDbSchema', __args__, opts=opts, typ=GetDbSchemaResult).value

    return AwaitableGetDbSchemaResult(
        changelog_script=pulumi.get(__ret__, 'changelog_script'),
        description=pulumi.get(__ret__, 'description'),
        id=pulumi.get(__ret__, 'id'),
        identifier=pulumi.get(__ret__, 'identifier'),
        migration_type=pulumi.get(__ret__, 'migration_type'),
        name=pulumi.get(__ret__, 'name'),
        org_id=pulumi.get(__ret__, 'org_id'),
        project_id=pulumi.get(__ret__, 'project_id'),
        schema_sources=pulumi.get(__ret__, 'schema_sources'),
        service=pulumi.get(__ret__, 'service'),
        tags=pulumi.get(__ret__, 'tags'),
        type=pulumi.get(__ret__, 'type'))
def get_db_schema_output(identifier: Optional[pulumi.Input[_builtins.str]] = None,
                         migration_type: Optional[pulumi.Input[Optional[_builtins.str]]] = None,
                         name: Optional[pulumi.Input[Optional[_builtins.str]]] = None,
                         org_id: Optional[pulumi.Input[_builtins.str]] = None,
                         project_id: Optional[pulumi.Input[_builtins.str]] = None,
                         type: Optional[pulumi.Input[Optional[_builtins.str]]] = None,
                         opts: Optional[Union[pulumi.InvokeOptions, pulumi.InvokeOutputOptions]] = None) -> pulumi.Output[GetDbSchemaResult]:
    """
    Data source for retrieving a Harness DBDevOps Schema.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_harness as harness

    example = harness.platform.get_db_schema(identifier="identifier",
        org_id="org_id",
        project_id="project_id")
    ```


    :param _builtins.str identifier: Unique identifier of the resource.
    :param _builtins.str migration_type: DB Migration tool type. Valid values are: Liquibase, Flyway
    :param _builtins.str name: Name of the resource.
    :param _builtins.str org_id: Unique identifier of the organization.
    :param _builtins.str project_id: Unique identifier of the project.
    :param _builtins.str type: Type of the database schema. Valid values are: Repository, Script
    """
    __args__ = dict()
    __args__['identifier'] = identifier
    __args__['migrationType'] = migration_type
    __args__['name'] = name
    __args__['orgId'] = org_id
    __args__['projectId'] = project_id
    __args__['type'] = type
    opts = pulumi.InvokeOutputOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke_output('harness:platform/getDbSchema:getDbSchema', __args__, opts=opts, typ=GetDbSchemaResult)
    return __ret__.apply(lambda __response__: GetDbSchemaResult(
        changelog_script=pulumi.get(__response__, 'changelog_script'),
        description=pulumi.get(__response__, 'description'),
        id=pulumi.get(__response__, 'id'),
        identifier=pulumi.get(__response__, 'identifier'),
        migration_type=pulumi.get(__response__, 'migration_type'),
        name=pulumi.get(__response__, 'name'),
        org_id=pulumi.get(__response__, 'org_id'),
        project_id=pulumi.get(__response__, 'project_id'),
        schema_sources=pulumi.get(__response__, 'schema_sources'),
        service=pulumi.get(__response__, 'service'),
        tags=pulumi.get(__response__, 'tags'),
        type=pulumi.get(__response__, 'type')))



# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities
from . import outputs

__all__ = [
    'GetInfraModulesResult',
    'AwaitableGetInfraModulesResult',
    'get_infra_modules',
    'get_infra_modules_output',
]

@pulumi.output_type
class GetInfraModulesResult:
    """
    A collection of values returned by getInfraModules.
    """
    def __init__(__self__, id=None, modules=None):
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if modules and not isinstance(modules, list):
            raise TypeError("Expected argument 'modules' to be a list")
        pulumi.set(__self__, "modules", modules)

    @_builtins.property
    @pulumi.getter
    def id(self) -> _builtins.str:
        """
        The provider-assigned unique ID for this managed resource.
        """
        return pulumi.get(self, "id")

    @_builtins.property
    @pulumi.getter
    def modules(self) -> Sequence['outputs.GetInfraModulesModuleResult']:
        """
        List of modules
        """
        return pulumi.get(self, "modules")


class AwaitableGetInfraModulesResult(GetInfraModulesResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetInfraModulesResult(
            id=self.id,
            modules=self.modules)


def get_infra_modules(opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetInfraModulesResult:
    """
    Data source for retrieving a list of modules from the module registry.

    ## Example Usage
    """
    __args__ = dict()
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('harness:platform/getInfraModules:getInfraModules', __args__, opts=opts, typ=GetInfraModulesResult).value

    return AwaitableGetInfraModulesResult(
        id=pulumi.get(__ret__, 'id'),
        modules=pulumi.get(__ret__, 'modules'))
def get_infra_modules_output(opts: Optional[Union[pulumi.InvokeOptions, pulumi.InvokeOutputOptions]] = None) -> pulumi.Output[GetInfraModulesResult]:
    """
    Data source for retrieving a list of modules from the module registry.

    ## Example Usage
    """
    __args__ = dict()
    opts = pulumi.InvokeOutputOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke_output('harness:platform/getInfraModules:getInfraModules', __args__, opts=opts, typ=GetInfraModulesResult)
    return __ret__.apply(lambda __response__: GetInfraModulesResult(
        id=pulumi.get(__response__, 'id'),
        modules=pulumi.get(__response__, 'modules')))



# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities

__all__ = [
    'GetGitopsAppProjectMappingResult',
    'AwaitableGetGitopsAppProjectMappingResult',
    'get_gitops_app_project_mapping',
    'get_gitops_app_project_mapping_output',
]

@pulumi.output_type
class GetGitopsAppProjectMappingResult:
    """
    A collection of values returned by getGitopsAppProjectMapping.
    """
    def __init__(__self__, account_id=None, agent_id=None, argo_project_name=None, auto_create_service_env=None, id=None, identifier=None, org_id=None, project_id=None):
        if account_id and not isinstance(account_id, str):
            raise TypeError("Expected argument 'account_id' to be a str")
        pulumi.set(__self__, "account_id", account_id)
        if agent_id and not isinstance(agent_id, str):
            raise TypeError("Expected argument 'agent_id' to be a str")
        pulumi.set(__self__, "agent_id", agent_id)
        if argo_project_name and not isinstance(argo_project_name, str):
            raise TypeError("Expected argument 'argo_project_name' to be a str")
        pulumi.set(__self__, "argo_project_name", argo_project_name)
        if auto_create_service_env and not isinstance(auto_create_service_env, bool):
            raise TypeError("Expected argument 'auto_create_service_env' to be a bool")
        pulumi.set(__self__, "auto_create_service_env", auto_create_service_env)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if identifier and not isinstance(identifier, str):
            raise TypeError("Expected argument 'identifier' to be a str")
        pulumi.set(__self__, "identifier", identifier)
        if org_id and not isinstance(org_id, str):
            raise TypeError("Expected argument 'org_id' to be a str")
        pulumi.set(__self__, "org_id", org_id)
        if project_id and not isinstance(project_id, str):
            raise TypeError("Expected argument 'project_id' to be a str")
        pulumi.set(__self__, "project_id", project_id)

    @_builtins.property
    @pulumi.getter(name="accountId")
    @_utilities.deprecated("""This field is deprecated and will be removed in a future release.""")
    def account_id(self) -> _builtins.str:
        """
        Account identifier of the GitOps agent's Application Project.
        """
        return pulumi.get(self, "account_id")

    @_builtins.property
    @pulumi.getter(name="agentId")
    def agent_id(self) -> _builtins.str:
        """
        Agent identifier for which the ArgoCD and Harness project mapping is to be created.
        """
        return pulumi.get(self, "agent_id")

    @_builtins.property
    @pulumi.getter(name="argoProjectName")
    def argo_project_name(self) -> _builtins.str:
        """
        ArgoCD Project name which is to be mapped to the Harness project.
        """
        return pulumi.get(self, "argo_project_name")

    @_builtins.property
    @pulumi.getter(name="autoCreateServiceEnv")
    def auto_create_service_env(self) -> _builtins.bool:
        """
        Enable automated creation of service, environment and cluster-env link. Defaults to false.
        """
        return pulumi.get(self, "auto_create_service_env")

    @_builtins.property
    @pulumi.getter
    def id(self) -> _builtins.str:
        """
        The provider-assigned unique ID for this managed resource.
        """
        return pulumi.get(self, "id")

    @_builtins.property
    @pulumi.getter
    def identifier(self) -> _builtins.str:
        """
        Identifier of the GitOps Application Project.
        """
        return pulumi.get(self, "identifier")

    @_builtins.property
    @pulumi.getter(name="orgId")
    def org_id(self) -> _builtins.str:
        """
        Organization identifier of the GitOps agent's Application Project.
        """
        return pulumi.get(self, "org_id")

    @_builtins.property
    @pulumi.getter(name="projectId")
    def project_id(self) -> _builtins.str:
        """
        Project identifier of the GitOps agent's Application Project.
        """
        return pulumi.get(self, "project_id")


class AwaitableGetGitopsAppProjectMappingResult(GetGitopsAppProjectMappingResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetGitopsAppProjectMappingResult(
            account_id=self.account_id,
            agent_id=self.agent_id,
            argo_project_name=self.argo_project_name,
            auto_create_service_env=self.auto_create_service_env,
            id=self.id,
            identifier=self.identifier,
            org_id=self.org_id,
            project_id=self.project_id)


def get_gitops_app_project_mapping(account_id: Optional[_builtins.str] = None,
                                   agent_id: Optional[_builtins.str] = None,
                                   argo_project_name: Optional[_builtins.str] = None,
                                   org_id: Optional[_builtins.str] = None,
                                   project_id: Optional[_builtins.str] = None,
                                   opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetGitopsAppProjectMappingResult:
    """
    Resource for managing the Harness GitOps Application Project Mappings.

    ## Example Usage


    :param _builtins.str account_id: Account identifier of the GitOps agent's Application Project.
    :param _builtins.str agent_id: Agent identifier for which the ArgoCD and Harness project mapping is to be created.
    :param _builtins.str argo_project_name: ArgoCD Project name which is to be mapped to the Harness project.
    :param _builtins.str org_id: Organization identifier of the GitOps agent's Application Project.
    :param _builtins.str project_id: Project identifier of the GitOps agent's Application Project.
    """
    __args__ = dict()
    __args__['accountId'] = account_id
    __args__['agentId'] = agent_id
    __args__['argoProjectName'] = argo_project_name
    __args__['orgId'] = org_id
    __args__['projectId'] = project_id
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('harness:platform/getGitopsAppProjectMapping:getGitopsAppProjectMapping', __args__, opts=opts, typ=GetGitopsAppProjectMappingResult).value

    return AwaitableGetGitopsAppProjectMappingResult(
        account_id=pulumi.get(__ret__, 'account_id'),
        agent_id=pulumi.get(__ret__, 'agent_id'),
        argo_project_name=pulumi.get(__ret__, 'argo_project_name'),
        auto_create_service_env=pulumi.get(__ret__, 'auto_create_service_env'),
        id=pulumi.get(__ret__, 'id'),
        identifier=pulumi.get(__ret__, 'identifier'),
        org_id=pulumi.get(__ret__, 'org_id'),
        project_id=pulumi.get(__ret__, 'project_id'))
def get_gitops_app_project_mapping_output(account_id: Optional[pulumi.Input[Optional[_builtins.str]]] = None,
                                          agent_id: Optional[pulumi.Input[_builtins.str]] = None,
                                          argo_project_name: Optional[pulumi.Input[_builtins.str]] = None,
                                          org_id: Optional[pulumi.Input[_builtins.str]] = None,
                                          project_id: Optional[pulumi.Input[_builtins.str]] = None,
                                          opts: Optional[Union[pulumi.InvokeOptions, pulumi.InvokeOutputOptions]] = None) -> pulumi.Output[GetGitopsAppProjectMappingResult]:
    """
    Resource for managing the Harness GitOps Application Project Mappings.

    ## Example Usage


    :param _builtins.str account_id: Account identifier of the GitOps agent's Application Project.
    :param _builtins.str agent_id: Agent identifier for which the ArgoCD and Harness project mapping is to be created.
    :param _builtins.str argo_project_name: ArgoCD Project name which is to be mapped to the Harness project.
    :param _builtins.str org_id: Organization identifier of the GitOps agent's Application Project.
    :param _builtins.str project_id: Project identifier of the GitOps agent's Application Project.
    """
    __args__ = dict()
    __args__['accountId'] = account_id
    __args__['agentId'] = agent_id
    __args__['argoProjectName'] = argo_project_name
    __args__['orgId'] = org_id
    __args__['projectId'] = project_id
    opts = pulumi.InvokeOutputOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke_output('harness:platform/getGitopsAppProjectMapping:getGitopsAppProjectMapping', __args__, opts=opts, typ=GetGitopsAppProjectMappingResult)
    return __ret__.apply(lambda __response__: GetGitopsAppProjectMappingResult(
        account_id=pulumi.get(__response__, 'account_id'),
        agent_id=pulumi.get(__response__, 'agent_id'),
        argo_project_name=pulumi.get(__response__, 'argo_project_name'),
        auto_create_service_env=pulumi.get(__response__, 'auto_create_service_env'),
        id=pulumi.get(__response__, 'id'),
        identifier=pulumi.get(__response__, 'identifier'),
        org_id=pulumi.get(__response__, 'org_id'),
        project_id=pulumi.get(__response__, 'project_id')))



# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities
from . import outputs
from ._inputs import *

__all__ = ['EnvironmentClustersMappingArgs', 'EnvironmentClustersMapping']

@pulumi.input_type
class EnvironmentClustersMappingArgs:
    def __init__(__self__, *,
                 env_id: pulumi.Input[_builtins.str],
                 identifier: pulumi.Input[_builtins.str],
                 clusters: Optional[pulumi.Input[Sequence[pulumi.Input['EnvironmentClustersMappingClusterArgs']]]] = None,
                 org_id: Optional[pulumi.Input[_builtins.str]] = None,
                 project_id: Optional[pulumi.Input[_builtins.str]] = None):
        """
        The set of arguments for constructing a EnvironmentClustersMapping resource.
        :param pulumi.Input[_builtins.str] env_id: environment identifier.
        :param pulumi.Input[_builtins.str] identifier: identifier for the cluster mapping(can be given any value).
        :param pulumi.Input[Sequence[pulumi.Input['EnvironmentClustersMappingClusterArgs']]] clusters: list of cluster identifiers and names
        :param pulumi.Input[_builtins.str] org_id: org_id of the environment.
        :param pulumi.Input[_builtins.str] project_id: project_id of the environment.
        """
        pulumi.set(__self__, "env_id", env_id)
        pulumi.set(__self__, "identifier", identifier)
        if clusters is not None:
            pulumi.set(__self__, "clusters", clusters)
        if org_id is not None:
            pulumi.set(__self__, "org_id", org_id)
        if project_id is not None:
            pulumi.set(__self__, "project_id", project_id)

    @_builtins.property
    @pulumi.getter(name="envId")
    def env_id(self) -> pulumi.Input[_builtins.str]:
        """
        environment identifier.
        """
        return pulumi.get(self, "env_id")

    @env_id.setter
    def env_id(self, value: pulumi.Input[_builtins.str]):
        pulumi.set(self, "env_id", value)

    @_builtins.property
    @pulumi.getter
    def identifier(self) -> pulumi.Input[_builtins.str]:
        """
        identifier for the cluster mapping(can be given any value).
        """
        return pulumi.get(self, "identifier")

    @identifier.setter
    def identifier(self, value: pulumi.Input[_builtins.str]):
        pulumi.set(self, "identifier", value)

    @_builtins.property
    @pulumi.getter
    def clusters(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['EnvironmentClustersMappingClusterArgs']]]]:
        """
        list of cluster identifiers and names
        """
        return pulumi.get(self, "clusters")

    @clusters.setter
    def clusters(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['EnvironmentClustersMappingClusterArgs']]]]):
        pulumi.set(self, "clusters", value)

    @_builtins.property
    @pulumi.getter(name="orgId")
    def org_id(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        org_id of the environment.
        """
        return pulumi.get(self, "org_id")

    @org_id.setter
    def org_id(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "org_id", value)

    @_builtins.property
    @pulumi.getter(name="projectId")
    def project_id(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        project_id of the environment.
        """
        return pulumi.get(self, "project_id")

    @project_id.setter
    def project_id(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "project_id", value)


@pulumi.input_type
class _EnvironmentClustersMappingState:
    def __init__(__self__, *,
                 clusters: Optional[pulumi.Input[Sequence[pulumi.Input['EnvironmentClustersMappingClusterArgs']]]] = None,
                 env_id: Optional[pulumi.Input[_builtins.str]] = None,
                 identifier: Optional[pulumi.Input[_builtins.str]] = None,
                 org_id: Optional[pulumi.Input[_builtins.str]] = None,
                 project_id: Optional[pulumi.Input[_builtins.str]] = None,
                 scope: Optional[pulumi.Input[_builtins.str]] = None):
        """
        Input properties used for looking up and filtering EnvironmentClustersMapping resources.
        :param pulumi.Input[Sequence[pulumi.Input['EnvironmentClustersMappingClusterArgs']]] clusters: list of cluster identifiers and names
        :param pulumi.Input[_builtins.str] env_id: environment identifier.
        :param pulumi.Input[_builtins.str] identifier: identifier for the cluster mapping(can be given any value).
        :param pulumi.Input[_builtins.str] org_id: org_id of the environment.
        :param pulumi.Input[_builtins.str] project_id: project_id of the environment.
        :param pulumi.Input[_builtins.str] scope: scope at which the environment exists in harness.
        """
        if clusters is not None:
            pulumi.set(__self__, "clusters", clusters)
        if env_id is not None:
            pulumi.set(__self__, "env_id", env_id)
        if identifier is not None:
            pulumi.set(__self__, "identifier", identifier)
        if org_id is not None:
            pulumi.set(__self__, "org_id", org_id)
        if project_id is not None:
            pulumi.set(__self__, "project_id", project_id)
        if scope is not None:
            pulumi.set(__self__, "scope", scope)

    @_builtins.property
    @pulumi.getter
    def clusters(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['EnvironmentClustersMappingClusterArgs']]]]:
        """
        list of cluster identifiers and names
        """
        return pulumi.get(self, "clusters")

    @clusters.setter
    def clusters(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['EnvironmentClustersMappingClusterArgs']]]]):
        pulumi.set(self, "clusters", value)

    @_builtins.property
    @pulumi.getter(name="envId")
    def env_id(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        environment identifier.
        """
        return pulumi.get(self, "env_id")

    @env_id.setter
    def env_id(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "env_id", value)

    @_builtins.property
    @pulumi.getter
    def identifier(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        identifier for the cluster mapping(can be given any value).
        """
        return pulumi.get(self, "identifier")

    @identifier.setter
    def identifier(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "identifier", value)

    @_builtins.property
    @pulumi.getter(name="orgId")
    def org_id(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        org_id of the environment.
        """
        return pulumi.get(self, "org_id")

    @org_id.setter
    def org_id(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "org_id", value)

    @_builtins.property
    @pulumi.getter(name="projectId")
    def project_id(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        project_id of the environment.
        """
        return pulumi.get(self, "project_id")

    @project_id.setter
    def project_id(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "project_id", value)

    @_builtins.property
    @pulumi.getter
    def scope(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        scope at which the environment exists in harness.
        """
        return pulumi.get(self, "scope")

    @scope.setter
    def scope(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "scope", value)


@pulumi.type_token("harness:platform/environmentClustersMapping:EnvironmentClustersMapping")
class EnvironmentClustersMapping(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 clusters: Optional[pulumi.Input[Sequence[pulumi.Input[Union['EnvironmentClustersMappingClusterArgs', 'EnvironmentClustersMappingClusterArgsDict']]]]] = None,
                 env_id: Optional[pulumi.Input[_builtins.str]] = None,
                 identifier: Optional[pulumi.Input[_builtins.str]] = None,
                 org_id: Optional[pulumi.Input[_builtins.str]] = None,
                 project_id: Optional[pulumi.Input[_builtins.str]] = None,
                 __props__=None):
        """
        Resource for mapping environment with Harness Clusters.

        ## Example Usage

        ```python
        import pulumi
        import pulumi_harness as harness

        # mapping a cluster to a project level env
        example = harness.platform.EnvironmentClustersMapping("example",
            identifier="mycustomidentifier",
            org_id="orgIdentifer",
            project_id="projectIdentifier",
            env_id="exampleEnvId",
            clusters=[{
                "identifier": "incluster",
                "name": "in-cluster",
                "agent_identifier": "account.gitopsagentdev",
                "scope": "ACCOUNT",
            }])
        # mapping two clusters to account level env
        example2 = harness.platform.EnvironmentClustersMapping("example2",
            identifier="mycustomidentifier",
            env_id="env1",
            clusters=[
                {
                    "identifier": "clusterA",
                    "name": "cluster-A",
                    "agent_identifier": "account.gitopsagentprod",
                    "scope": "ACCOUNT",
                },
                {
                    "identifier": "clusterB",
                    "name": "cluster-B",
                    "agent_identifier": "account.gitopsagentprod",
                    "scope": "ACCOUNT",
                },
            ])
        ```

        ## Import

        The `pulumi import` command can be used, for example:

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[Sequence[pulumi.Input[Union['EnvironmentClustersMappingClusterArgs', 'EnvironmentClustersMappingClusterArgsDict']]]] clusters: list of cluster identifiers and names
        :param pulumi.Input[_builtins.str] env_id: environment identifier.
        :param pulumi.Input[_builtins.str] identifier: identifier for the cluster mapping(can be given any value).
        :param pulumi.Input[_builtins.str] org_id: org_id of the environment.
        :param pulumi.Input[_builtins.str] project_id: project_id of the environment.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: EnvironmentClustersMappingArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        Resource for mapping environment with Harness Clusters.

        ## Example Usage

        ```python
        import pulumi
        import pulumi_harness as harness

        # mapping a cluster to a project level env
        example = harness.platform.EnvironmentClustersMapping("example",
            identifier="mycustomidentifier",
            org_id="orgIdentifer",
            project_id="projectIdentifier",
            env_id="exampleEnvId",
            clusters=[{
                "identifier": "incluster",
                "name": "in-cluster",
                "agent_identifier": "account.gitopsagentdev",
                "scope": "ACCOUNT",
            }])
        # mapping two clusters to account level env
        example2 = harness.platform.EnvironmentClustersMapping("example2",
            identifier="mycustomidentifier",
            env_id="env1",
            clusters=[
                {
                    "identifier": "clusterA",
                    "name": "cluster-A",
                    "agent_identifier": "account.gitopsagentprod",
                    "scope": "ACCOUNT",
                },
                {
                    "identifier": "clusterB",
                    "name": "cluster-B",
                    "agent_identifier": "account.gitopsagentprod",
                    "scope": "ACCOUNT",
                },
            ])
        ```

        ## Import

        The `pulumi import` command can be used, for example:

        :param str resource_name: The name of the resource.
        :param EnvironmentClustersMappingArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(EnvironmentClustersMappingArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 clusters: Optional[pulumi.Input[Sequence[pulumi.Input[Union['EnvironmentClustersMappingClusterArgs', 'EnvironmentClustersMappingClusterArgsDict']]]]] = None,
                 env_id: Optional[pulumi.Input[_builtins.str]] = None,
                 identifier: Optional[pulumi.Input[_builtins.str]] = None,
                 org_id: Optional[pulumi.Input[_builtins.str]] = None,
                 project_id: Optional[pulumi.Input[_builtins.str]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = EnvironmentClustersMappingArgs.__new__(EnvironmentClustersMappingArgs)

            __props__.__dict__["clusters"] = clusters
            if env_id is None and not opts.urn:
                raise TypeError("Missing required property 'env_id'")
            __props__.__dict__["env_id"] = env_id
            if identifier is None and not opts.urn:
                raise TypeError("Missing required property 'identifier'")
            __props__.__dict__["identifier"] = identifier
            __props__.__dict__["org_id"] = org_id
            __props__.__dict__["project_id"] = project_id
            __props__.__dict__["scope"] = None
        super(EnvironmentClustersMapping, __self__).__init__(
            'harness:platform/environmentClustersMapping:EnvironmentClustersMapping',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            clusters: Optional[pulumi.Input[Sequence[pulumi.Input[Union['EnvironmentClustersMappingClusterArgs', 'EnvironmentClustersMappingClusterArgsDict']]]]] = None,
            env_id: Optional[pulumi.Input[_builtins.str]] = None,
            identifier: Optional[pulumi.Input[_builtins.str]] = None,
            org_id: Optional[pulumi.Input[_builtins.str]] = None,
            project_id: Optional[pulumi.Input[_builtins.str]] = None,
            scope: Optional[pulumi.Input[_builtins.str]] = None) -> 'EnvironmentClustersMapping':
        """
        Get an existing EnvironmentClustersMapping resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[Sequence[pulumi.Input[Union['EnvironmentClustersMappingClusterArgs', 'EnvironmentClustersMappingClusterArgsDict']]]] clusters: list of cluster identifiers and names
        :param pulumi.Input[_builtins.str] env_id: environment identifier.
        :param pulumi.Input[_builtins.str] identifier: identifier for the cluster mapping(can be given any value).
        :param pulumi.Input[_builtins.str] org_id: org_id of the environment.
        :param pulumi.Input[_builtins.str] project_id: project_id of the environment.
        :param pulumi.Input[_builtins.str] scope: scope at which the environment exists in harness.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _EnvironmentClustersMappingState.__new__(_EnvironmentClustersMappingState)

        __props__.__dict__["clusters"] = clusters
        __props__.__dict__["env_id"] = env_id
        __props__.__dict__["identifier"] = identifier
        __props__.__dict__["org_id"] = org_id
        __props__.__dict__["project_id"] = project_id
        __props__.__dict__["scope"] = scope
        return EnvironmentClustersMapping(resource_name, opts=opts, __props__=__props__)

    @_builtins.property
    @pulumi.getter
    def clusters(self) -> pulumi.Output[Optional[Sequence['outputs.EnvironmentClustersMappingCluster']]]:
        """
        list of cluster identifiers and names
        """
        return pulumi.get(self, "clusters")

    @_builtins.property
    @pulumi.getter(name="envId")
    def env_id(self) -> pulumi.Output[_builtins.str]:
        """
        environment identifier.
        """
        return pulumi.get(self, "env_id")

    @_builtins.property
    @pulumi.getter
    def identifier(self) -> pulumi.Output[_builtins.str]:
        """
        identifier for the cluster mapping(can be given any value).
        """
        return pulumi.get(self, "identifier")

    @_builtins.property
    @pulumi.getter(name="orgId")
    def org_id(self) -> pulumi.Output[Optional[_builtins.str]]:
        """
        org_id of the environment.
        """
        return pulumi.get(self, "org_id")

    @_builtins.property
    @pulumi.getter(name="projectId")
    def project_id(self) -> pulumi.Output[Optional[_builtins.str]]:
        """
        project_id of the environment.
        """
        return pulumi.get(self, "project_id")

    @_builtins.property
    @pulumi.getter
    def scope(self) -> pulumi.Output[_builtins.str]:
        """
        scope at which the environment exists in harness.
        """
        return pulumi.get(self, "scope")




# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities
from . import outputs
from ._inputs import *

__all__ = ['PipelineCentralNotificationRuleArgs', 'PipelineCentralNotificationRule']

@pulumi.input_type
class PipelineCentralNotificationRuleArgs:
    def __init__(__self__, *,
                 identifier: pulumi.Input[_builtins.str],
                 notification_channel_refs: pulumi.Input[Sequence[pulumi.Input[_builtins.str]]],
                 notification_conditions: pulumi.Input[Sequence[pulumi.Input['PipelineCentralNotificationRuleNotificationConditionArgs']]],
                 custom_notification_template_ref: Optional[pulumi.Input['PipelineCentralNotificationRuleCustomNotificationTemplateRefArgs']] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 org: Optional[pulumi.Input[_builtins.str]] = None,
                 project: Optional[pulumi.Input[_builtins.str]] = None,
                 status: Optional[pulumi.Input[_builtins.str]] = None):
        """
        The set of arguments for constructing a PipelineCentralNotificationRule resource.
        """
        pulumi.set(__self__, "identifier", identifier)
        pulumi.set(__self__, "notification_channel_refs", notification_channel_refs)
        pulumi.set(__self__, "notification_conditions", notification_conditions)
        if custom_notification_template_ref is not None:
            pulumi.set(__self__, "custom_notification_template_ref", custom_notification_template_ref)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if org is not None:
            pulumi.set(__self__, "org", org)
        if project is not None:
            pulumi.set(__self__, "project", project)
        if status is not None:
            pulumi.set(__self__, "status", status)

    @_builtins.property
    @pulumi.getter
    def identifier(self) -> pulumi.Input[_builtins.str]:
        return pulumi.get(self, "identifier")

    @identifier.setter
    def identifier(self, value: pulumi.Input[_builtins.str]):
        pulumi.set(self, "identifier", value)

    @_builtins.property
    @pulumi.getter(name="notificationChannelRefs")
    def notification_channel_refs(self) -> pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]:
        return pulumi.get(self, "notification_channel_refs")

    @notification_channel_refs.setter
    def notification_channel_refs(self, value: pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]):
        pulumi.set(self, "notification_channel_refs", value)

    @_builtins.property
    @pulumi.getter(name="notificationConditions")
    def notification_conditions(self) -> pulumi.Input[Sequence[pulumi.Input['PipelineCentralNotificationRuleNotificationConditionArgs']]]:
        return pulumi.get(self, "notification_conditions")

    @notification_conditions.setter
    def notification_conditions(self, value: pulumi.Input[Sequence[pulumi.Input['PipelineCentralNotificationRuleNotificationConditionArgs']]]):
        pulumi.set(self, "notification_conditions", value)

    @_builtins.property
    @pulumi.getter(name="customNotificationTemplateRef")
    def custom_notification_template_ref(self) -> Optional[pulumi.Input['PipelineCentralNotificationRuleCustomNotificationTemplateRefArgs']]:
        return pulumi.get(self, "custom_notification_template_ref")

    @custom_notification_template_ref.setter
    def custom_notification_template_ref(self, value: Optional[pulumi.Input['PipelineCentralNotificationRuleCustomNotificationTemplateRefArgs']]):
        pulumi.set(self, "custom_notification_template_ref", value)

    @_builtins.property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[_builtins.str]]:
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "name", value)

    @_builtins.property
    @pulumi.getter
    def org(self) -> Optional[pulumi.Input[_builtins.str]]:
        return pulumi.get(self, "org")

    @org.setter
    def org(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "org", value)

    @_builtins.property
    @pulumi.getter
    def project(self) -> Optional[pulumi.Input[_builtins.str]]:
        return pulumi.get(self, "project")

    @project.setter
    def project(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "project", value)

    @_builtins.property
    @pulumi.getter
    def status(self) -> Optional[pulumi.Input[_builtins.str]]:
        return pulumi.get(self, "status")

    @status.setter
    def status(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "status", value)


@pulumi.input_type
class _PipelineCentralNotificationRuleState:
    def __init__(__self__, *,
                 account: Optional[pulumi.Input[_builtins.str]] = None,
                 created: Optional[pulumi.Input[_builtins.int]] = None,
                 custom_notification_template_ref: Optional[pulumi.Input['PipelineCentralNotificationRuleCustomNotificationTemplateRefArgs']] = None,
                 identifier: Optional[pulumi.Input[_builtins.str]] = None,
                 last_modified: Optional[pulumi.Input[_builtins.int]] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 notification_channel_refs: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
                 notification_conditions: Optional[pulumi.Input[Sequence[pulumi.Input['PipelineCentralNotificationRuleNotificationConditionArgs']]]] = None,
                 org: Optional[pulumi.Input[_builtins.str]] = None,
                 project: Optional[pulumi.Input[_builtins.str]] = None,
                 status: Optional[pulumi.Input[_builtins.str]] = None):
        """
        Input properties used for looking up and filtering PipelineCentralNotificationRule resources.
        :param pulumi.Input[_builtins.str] account: Account identifier associated with this notification channel.
        :param pulumi.Input[_builtins.int] created: Timestamp when the notification rule was created.
        :param pulumi.Input[_builtins.int] last_modified: Timestamp when the notification rule was last modified.
        """
        if account is not None:
            pulumi.set(__self__, "account", account)
        if created is not None:
            pulumi.set(__self__, "created", created)
        if custom_notification_template_ref is not None:
            pulumi.set(__self__, "custom_notification_template_ref", custom_notification_template_ref)
        if identifier is not None:
            pulumi.set(__self__, "identifier", identifier)
        if last_modified is not None:
            pulumi.set(__self__, "last_modified", last_modified)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if notification_channel_refs is not None:
            pulumi.set(__self__, "notification_channel_refs", notification_channel_refs)
        if notification_conditions is not None:
            pulumi.set(__self__, "notification_conditions", notification_conditions)
        if org is not None:
            pulumi.set(__self__, "org", org)
        if project is not None:
            pulumi.set(__self__, "project", project)
        if status is not None:
            pulumi.set(__self__, "status", status)

    @_builtins.property
    @pulumi.getter
    def account(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Account identifier associated with this notification channel.
        """
        return pulumi.get(self, "account")

    @account.setter
    def account(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "account", value)

    @_builtins.property
    @pulumi.getter
    def created(self) -> Optional[pulumi.Input[_builtins.int]]:
        """
        Timestamp when the notification rule was created.
        """
        return pulumi.get(self, "created")

    @created.setter
    def created(self, value: Optional[pulumi.Input[_builtins.int]]):
        pulumi.set(self, "created", value)

    @_builtins.property
    @pulumi.getter(name="customNotificationTemplateRef")
    def custom_notification_template_ref(self) -> Optional[pulumi.Input['PipelineCentralNotificationRuleCustomNotificationTemplateRefArgs']]:
        return pulumi.get(self, "custom_notification_template_ref")

    @custom_notification_template_ref.setter
    def custom_notification_template_ref(self, value: Optional[pulumi.Input['PipelineCentralNotificationRuleCustomNotificationTemplateRefArgs']]):
        pulumi.set(self, "custom_notification_template_ref", value)

    @_builtins.property
    @pulumi.getter
    def identifier(self) -> Optional[pulumi.Input[_builtins.str]]:
        return pulumi.get(self, "identifier")

    @identifier.setter
    def identifier(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "identifier", value)

    @_builtins.property
    @pulumi.getter(name="lastModified")
    def last_modified(self) -> Optional[pulumi.Input[_builtins.int]]:
        """
        Timestamp when the notification rule was last modified.
        """
        return pulumi.get(self, "last_modified")

    @last_modified.setter
    def last_modified(self, value: Optional[pulumi.Input[_builtins.int]]):
        pulumi.set(self, "last_modified", value)

    @_builtins.property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[_builtins.str]]:
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "name", value)

    @_builtins.property
    @pulumi.getter(name="notificationChannelRefs")
    def notification_channel_refs(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]:
        return pulumi.get(self, "notification_channel_refs")

    @notification_channel_refs.setter
    def notification_channel_refs(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]):
        pulumi.set(self, "notification_channel_refs", value)

    @_builtins.property
    @pulumi.getter(name="notificationConditions")
    def notification_conditions(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['PipelineCentralNotificationRuleNotificationConditionArgs']]]]:
        return pulumi.get(self, "notification_conditions")

    @notification_conditions.setter
    def notification_conditions(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['PipelineCentralNotificationRuleNotificationConditionArgs']]]]):
        pulumi.set(self, "notification_conditions", value)

    @_builtins.property
    @pulumi.getter
    def org(self) -> Optional[pulumi.Input[_builtins.str]]:
        return pulumi.get(self, "org")

    @org.setter
    def org(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "org", value)

    @_builtins.property
    @pulumi.getter
    def project(self) -> Optional[pulumi.Input[_builtins.str]]:
        return pulumi.get(self, "project")

    @project.setter
    def project(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "project", value)

    @_builtins.property
    @pulumi.getter
    def status(self) -> Optional[pulumi.Input[_builtins.str]]:
        return pulumi.get(self, "status")

    @status.setter
    def status(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "status", value)


@pulumi.type_token("harness:platform/pipelineCentralNotificationRule:PipelineCentralNotificationRule")
class PipelineCentralNotificationRule(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 custom_notification_template_ref: Optional[pulumi.Input[Union['PipelineCentralNotificationRuleCustomNotificationTemplateRefArgs', 'PipelineCentralNotificationRuleCustomNotificationTemplateRefArgsDict']]] = None,
                 identifier: Optional[pulumi.Input[_builtins.str]] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 notification_channel_refs: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
                 notification_conditions: Optional[pulumi.Input[Sequence[pulumi.Input[Union['PipelineCentralNotificationRuleNotificationConditionArgs', 'PipelineCentralNotificationRuleNotificationConditionArgsDict']]]]] = None,
                 org: Optional[pulumi.Input[_builtins.str]] = None,
                 project: Optional[pulumi.Input[_builtins.str]] = None,
                 status: Optional[pulumi.Input[_builtins.str]] = None,
                 __props__=None):
        """
        Resource for creating a Harness Notification Rule for Pipeline

        ## Example Usage

        ```python
        import pulumi
        import pulumi_harness as harness

        proj_example = harness.platform.PipelineCentralNotificationRule("projExample",
            identifier="identifier",
            name="name",
            status="ENABLED",
            notification_channel_refs=["account.channel"],
            org="default",
            project="proj0",
            notification_conditions=[{
                "condition_name": "pipelineRuleProjectConditionName",
                "notification_event_configs": [{
                    "notification_entity": "PIPELINE",
                    "notification_event": "PIPELINE_START",
                    "notification_event_datas": [{
                        "type": "PIPELINE",
                        "scope_identifiers": [],
                    }],
                    "entity_identifiers": [],
                }],
            }])
        org_example = harness.platform.PipelineCentralNotificationRule("orgExample",
            identifier="identifier",
            name="name",
            status="ENABLED",
            notification_channel_refs=["channel"],
            org="default",
            notification_conditions=[{
                "condition_name": "pipelineRuleOrgConditionName",
                "notification_event_configs": [{
                    "notification_entity": "PIPELINE",
                    "notification_event": "PIPELINE_START",
                    "notification_event_datas": [{
                        "type": "PIPELINE",
                        "scope_identifiers": [
                            "proj0",
                            "random",
                        ],
                    }],
                    "entity_identifiers": [],
                }],
            }])
        account_example = harness.platform.PipelineCentralNotificationRule("accountExample",
            identifier="identifier",
            name="name",
            status="DISABLED",
            notification_channel_refs=["org.channel"],
            notification_conditions=[{
                "condition_name": "pipelineRuleConditionName",
                "notification_event_configs": [{
                    "notification_entity": "PIPELINE",
                    "notification_event": "PIPELINE_START",
                    "notification_event_datas": [{
                        "type": "PIPELINE",
                        "scope_identifiers": ["org"],
                    }],
                    "entity_identifiers": [],
                }],
            }])
        ```

        ## Import

        The `pulumi import` command can be used, for example:

        Import account level pipeline central notification rule

        ```sh
        $ pulumi import harness:platform/pipelineCentralNotificationRule:PipelineCentralNotificationRule example <notification_rule_id>
        ```

        Import org level pipeline central notification rule

        ```sh
        $ pulumi import harness:platform/pipelineCentralNotificationRule:PipelineCentralNotificationRule example <ord_id>/<notification_rule_id>
        ```

        Import project level pipeline central notification rule

        ```sh
        $ pulumi import harness:platform/pipelineCentralNotificationRule:PipelineCentralNotificationRule example <org_id>/<project_id>/<notification_rule_id>
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: PipelineCentralNotificationRuleArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        Resource for creating a Harness Notification Rule for Pipeline

        ## Example Usage

        ```python
        import pulumi
        import pulumi_harness as harness

        proj_example = harness.platform.PipelineCentralNotificationRule("projExample",
            identifier="identifier",
            name="name",
            status="ENABLED",
            notification_channel_refs=["account.channel"],
            org="default",
            project="proj0",
            notification_conditions=[{
                "condition_name": "pipelineRuleProjectConditionName",
                "notification_event_configs": [{
                    "notification_entity": "PIPELINE",
                    "notification_event": "PIPELINE_START",
                    "notification_event_datas": [{
                        "type": "PIPELINE",
                        "scope_identifiers": [],
                    }],
                    "entity_identifiers": [],
                }],
            }])
        org_example = harness.platform.PipelineCentralNotificationRule("orgExample",
            identifier="identifier",
            name="name",
            status="ENABLED",
            notification_channel_refs=["channel"],
            org="default",
            notification_conditions=[{
                "condition_name": "pipelineRuleOrgConditionName",
                "notification_event_configs": [{
                    "notification_entity": "PIPELINE",
                    "notification_event": "PIPELINE_START",
                    "notification_event_datas": [{
                        "type": "PIPELINE",
                        "scope_identifiers": [
                            "proj0",
                            "random",
                        ],
                    }],
                    "entity_identifiers": [],
                }],
            }])
        account_example = harness.platform.PipelineCentralNotificationRule("accountExample",
            identifier="identifier",
            name="name",
            status="DISABLED",
            notification_channel_refs=["org.channel"],
            notification_conditions=[{
                "condition_name": "pipelineRuleConditionName",
                "notification_event_configs": [{
                    "notification_entity": "PIPELINE",
                    "notification_event": "PIPELINE_START",
                    "notification_event_datas": [{
                        "type": "PIPELINE",
                        "scope_identifiers": ["org"],
                    }],
                    "entity_identifiers": [],
                }],
            }])
        ```

        ## Import

        The `pulumi import` command can be used, for example:

        Import account level pipeline central notification rule

        ```sh
        $ pulumi import harness:platform/pipelineCentralNotificationRule:PipelineCentralNotificationRule example <notification_rule_id>
        ```

        Import org level pipeline central notification rule

        ```sh
        $ pulumi import harness:platform/pipelineCentralNotificationRule:PipelineCentralNotificationRule example <ord_id>/<notification_rule_id>
        ```

        Import project level pipeline central notification rule

        ```sh
        $ pulumi import harness:platform/pipelineCentralNotificationRule:PipelineCentralNotificationRule example <org_id>/<project_id>/<notification_rule_id>
        ```

        :param str resource_name: The name of the resource.
        :param PipelineCentralNotificationRuleArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(PipelineCentralNotificationRuleArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 custom_notification_template_ref: Optional[pulumi.Input[Union['PipelineCentralNotificationRuleCustomNotificationTemplateRefArgs', 'PipelineCentralNotificationRuleCustomNotificationTemplateRefArgsDict']]] = None,
                 identifier: Optional[pulumi.Input[_builtins.str]] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 notification_channel_refs: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
                 notification_conditions: Optional[pulumi.Input[Sequence[pulumi.Input[Union['PipelineCentralNotificationRuleNotificationConditionArgs', 'PipelineCentralNotificationRuleNotificationConditionArgsDict']]]]] = None,
                 org: Optional[pulumi.Input[_builtins.str]] = None,
                 project: Optional[pulumi.Input[_builtins.str]] = None,
                 status: Optional[pulumi.Input[_builtins.str]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = PipelineCentralNotificationRuleArgs.__new__(PipelineCentralNotificationRuleArgs)

            __props__.__dict__["custom_notification_template_ref"] = custom_notification_template_ref
            if identifier is None and not opts.urn:
                raise TypeError("Missing required property 'identifier'")
            __props__.__dict__["identifier"] = identifier
            __props__.__dict__["name"] = name
            if notification_channel_refs is None and not opts.urn:
                raise TypeError("Missing required property 'notification_channel_refs'")
            __props__.__dict__["notification_channel_refs"] = notification_channel_refs
            if notification_conditions is None and not opts.urn:
                raise TypeError("Missing required property 'notification_conditions'")
            __props__.__dict__["notification_conditions"] = notification_conditions
            __props__.__dict__["org"] = org
            __props__.__dict__["project"] = project
            __props__.__dict__["status"] = status
            __props__.__dict__["account"] = None
            __props__.__dict__["created"] = None
            __props__.__dict__["last_modified"] = None
        super(PipelineCentralNotificationRule, __self__).__init__(
            'harness:platform/pipelineCentralNotificationRule:PipelineCentralNotificationRule',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            account: Optional[pulumi.Input[_builtins.str]] = None,
            created: Optional[pulumi.Input[_builtins.int]] = None,
            custom_notification_template_ref: Optional[pulumi.Input[Union['PipelineCentralNotificationRuleCustomNotificationTemplateRefArgs', 'PipelineCentralNotificationRuleCustomNotificationTemplateRefArgsDict']]] = None,
            identifier: Optional[pulumi.Input[_builtins.str]] = None,
            last_modified: Optional[pulumi.Input[_builtins.int]] = None,
            name: Optional[pulumi.Input[_builtins.str]] = None,
            notification_channel_refs: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
            notification_conditions: Optional[pulumi.Input[Sequence[pulumi.Input[Union['PipelineCentralNotificationRuleNotificationConditionArgs', 'PipelineCentralNotificationRuleNotificationConditionArgsDict']]]]] = None,
            org: Optional[pulumi.Input[_builtins.str]] = None,
            project: Optional[pulumi.Input[_builtins.str]] = None,
            status: Optional[pulumi.Input[_builtins.str]] = None) -> 'PipelineCentralNotificationRule':
        """
        Get an existing PipelineCentralNotificationRule resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[_builtins.str] account: Account identifier associated with this notification channel.
        :param pulumi.Input[_builtins.int] created: Timestamp when the notification rule was created.
        :param pulumi.Input[_builtins.int] last_modified: Timestamp when the notification rule was last modified.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _PipelineCentralNotificationRuleState.__new__(_PipelineCentralNotificationRuleState)

        __props__.__dict__["account"] = account
        __props__.__dict__["created"] = created
        __props__.__dict__["custom_notification_template_ref"] = custom_notification_template_ref
        __props__.__dict__["identifier"] = identifier
        __props__.__dict__["last_modified"] = last_modified
        __props__.__dict__["name"] = name
        __props__.__dict__["notification_channel_refs"] = notification_channel_refs
        __props__.__dict__["notification_conditions"] = notification_conditions
        __props__.__dict__["org"] = org
        __props__.__dict__["project"] = project
        __props__.__dict__["status"] = status
        return PipelineCentralNotificationRule(resource_name, opts=opts, __props__=__props__)

    @_builtins.property
    @pulumi.getter
    def account(self) -> pulumi.Output[_builtins.str]:
        """
        Account identifier associated with this notification channel.
        """
        return pulumi.get(self, "account")

    @_builtins.property
    @pulumi.getter
    def created(self) -> pulumi.Output[_builtins.int]:
        """
        Timestamp when the notification rule was created.
        """
        return pulumi.get(self, "created")

    @_builtins.property
    @pulumi.getter(name="customNotificationTemplateRef")
    def custom_notification_template_ref(self) -> pulumi.Output[Optional['outputs.PipelineCentralNotificationRuleCustomNotificationTemplateRef']]:
        return pulumi.get(self, "custom_notification_template_ref")

    @_builtins.property
    @pulumi.getter
    def identifier(self) -> pulumi.Output[_builtins.str]:
        return pulumi.get(self, "identifier")

    @_builtins.property
    @pulumi.getter(name="lastModified")
    def last_modified(self) -> pulumi.Output[_builtins.int]:
        """
        Timestamp when the notification rule was last modified.
        """
        return pulumi.get(self, "last_modified")

    @_builtins.property
    @pulumi.getter
    def name(self) -> pulumi.Output[_builtins.str]:
        return pulumi.get(self, "name")

    @_builtins.property
    @pulumi.getter(name="notificationChannelRefs")
    def notification_channel_refs(self) -> pulumi.Output[Sequence[_builtins.str]]:
        return pulumi.get(self, "notification_channel_refs")

    @_builtins.property
    @pulumi.getter(name="notificationConditions")
    def notification_conditions(self) -> pulumi.Output[Sequence['outputs.PipelineCentralNotificationRuleNotificationCondition']]:
        return pulumi.get(self, "notification_conditions")

    @_builtins.property
    @pulumi.getter
    def org(self) -> pulumi.Output[Optional[_builtins.str]]:
        return pulumi.get(self, "org")

    @_builtins.property
    @pulumi.getter
    def project(self) -> pulumi.Output[Optional[_builtins.str]]:
        return pulumi.get(self, "project")

    @_builtins.property
    @pulumi.getter
    def status(self) -> pulumi.Output[Optional[_builtins.str]]:
        return pulumi.get(self, "status")




# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities
from . import outputs
from ._inputs import *

__all__ = ['RoleAssignmentsArgs', 'RoleAssignments']

@pulumi.input_type
class RoleAssignmentsArgs:
    def __init__(__self__, *,
                 principals: pulumi.Input[Sequence[pulumi.Input['RoleAssignmentsPrincipalArgs']]],
                 resource_group_identifier: pulumi.Input[_builtins.str],
                 role_identifier: pulumi.Input[_builtins.str],
                 disabled: Optional[pulumi.Input[_builtins.bool]] = None,
                 identifier: Optional[pulumi.Input[_builtins.str]] = None,
                 managed: Optional[pulumi.Input[_builtins.bool]] = None,
                 org_id: Optional[pulumi.Input[_builtins.str]] = None,
                 project_id: Optional[pulumi.Input[_builtins.str]] = None):
        """
        The set of arguments for constructing a RoleAssignments resource.
        :param pulumi.Input[Sequence[pulumi.Input['RoleAssignmentsPrincipalArgs']]] principals: Principal.
        :param pulumi.Input[_builtins.str] resource_group_identifier: Resource group identifier.
        :param pulumi.Input[_builtins.str] role_identifier: Role identifier.
        :param pulumi.Input[_builtins.bool] disabled: Disabled or not.
        :param pulumi.Input[_builtins.str] identifier: Identifier for role assignment.
        :param pulumi.Input[_builtins.bool] managed: Managed or not.
        :param pulumi.Input[_builtins.str] org_id: Org identifier.
        :param pulumi.Input[_builtins.str] project_id: Project Identifier
        """
        pulumi.set(__self__, "principals", principals)
        pulumi.set(__self__, "resource_group_identifier", resource_group_identifier)
        pulumi.set(__self__, "role_identifier", role_identifier)
        if disabled is not None:
            pulumi.set(__self__, "disabled", disabled)
        if identifier is not None:
            pulumi.set(__self__, "identifier", identifier)
        if managed is not None:
            pulumi.set(__self__, "managed", managed)
        if org_id is not None:
            pulumi.set(__self__, "org_id", org_id)
        if project_id is not None:
            pulumi.set(__self__, "project_id", project_id)

    @_builtins.property
    @pulumi.getter
    def principals(self) -> pulumi.Input[Sequence[pulumi.Input['RoleAssignmentsPrincipalArgs']]]:
        """
        Principal.
        """
        return pulumi.get(self, "principals")

    @principals.setter
    def principals(self, value: pulumi.Input[Sequence[pulumi.Input['RoleAssignmentsPrincipalArgs']]]):
        pulumi.set(self, "principals", value)

    @_builtins.property
    @pulumi.getter(name="resourceGroupIdentifier")
    def resource_group_identifier(self) -> pulumi.Input[_builtins.str]:
        """
        Resource group identifier.
        """
        return pulumi.get(self, "resource_group_identifier")

    @resource_group_identifier.setter
    def resource_group_identifier(self, value: pulumi.Input[_builtins.str]):
        pulumi.set(self, "resource_group_identifier", value)

    @_builtins.property
    @pulumi.getter(name="roleIdentifier")
    def role_identifier(self) -> pulumi.Input[_builtins.str]:
        """
        Role identifier.
        """
        return pulumi.get(self, "role_identifier")

    @role_identifier.setter
    def role_identifier(self, value: pulumi.Input[_builtins.str]):
        pulumi.set(self, "role_identifier", value)

    @_builtins.property
    @pulumi.getter
    def disabled(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        Disabled or not.
        """
        return pulumi.get(self, "disabled")

    @disabled.setter
    def disabled(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "disabled", value)

    @_builtins.property
    @pulumi.getter
    def identifier(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Identifier for role assignment.
        """
        return pulumi.get(self, "identifier")

    @identifier.setter
    def identifier(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "identifier", value)

    @_builtins.property
    @pulumi.getter
    def managed(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        Managed or not.
        """
        return pulumi.get(self, "managed")

    @managed.setter
    def managed(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "managed", value)

    @_builtins.property
    @pulumi.getter(name="orgId")
    def org_id(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Org identifier.
        """
        return pulumi.get(self, "org_id")

    @org_id.setter
    def org_id(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "org_id", value)

    @_builtins.property
    @pulumi.getter(name="projectId")
    def project_id(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Project Identifier
        """
        return pulumi.get(self, "project_id")

    @project_id.setter
    def project_id(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "project_id", value)


@pulumi.input_type
class _RoleAssignmentsState:
    def __init__(__self__, *,
                 disabled: Optional[pulumi.Input[_builtins.bool]] = None,
                 identifier: Optional[pulumi.Input[_builtins.str]] = None,
                 managed: Optional[pulumi.Input[_builtins.bool]] = None,
                 org_id: Optional[pulumi.Input[_builtins.str]] = None,
                 principals: Optional[pulumi.Input[Sequence[pulumi.Input['RoleAssignmentsPrincipalArgs']]]] = None,
                 project_id: Optional[pulumi.Input[_builtins.str]] = None,
                 resource_group_identifier: Optional[pulumi.Input[_builtins.str]] = None,
                 role_identifier: Optional[pulumi.Input[_builtins.str]] = None):
        """
        Input properties used for looking up and filtering RoleAssignments resources.
        :param pulumi.Input[_builtins.bool] disabled: Disabled or not.
        :param pulumi.Input[_builtins.str] identifier: Identifier for role assignment.
        :param pulumi.Input[_builtins.bool] managed: Managed or not.
        :param pulumi.Input[_builtins.str] org_id: Org identifier.
        :param pulumi.Input[Sequence[pulumi.Input['RoleAssignmentsPrincipalArgs']]] principals: Principal.
        :param pulumi.Input[_builtins.str] project_id: Project Identifier
        :param pulumi.Input[_builtins.str] resource_group_identifier: Resource group identifier.
        :param pulumi.Input[_builtins.str] role_identifier: Role identifier.
        """
        if disabled is not None:
            pulumi.set(__self__, "disabled", disabled)
        if identifier is not None:
            pulumi.set(__self__, "identifier", identifier)
        if managed is not None:
            pulumi.set(__self__, "managed", managed)
        if org_id is not None:
            pulumi.set(__self__, "org_id", org_id)
        if principals is not None:
            pulumi.set(__self__, "principals", principals)
        if project_id is not None:
            pulumi.set(__self__, "project_id", project_id)
        if resource_group_identifier is not None:
            pulumi.set(__self__, "resource_group_identifier", resource_group_identifier)
        if role_identifier is not None:
            pulumi.set(__self__, "role_identifier", role_identifier)

    @_builtins.property
    @pulumi.getter
    def disabled(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        Disabled or not.
        """
        return pulumi.get(self, "disabled")

    @disabled.setter
    def disabled(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "disabled", value)

    @_builtins.property
    @pulumi.getter
    def identifier(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Identifier for role assignment.
        """
        return pulumi.get(self, "identifier")

    @identifier.setter
    def identifier(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "identifier", value)

    @_builtins.property
    @pulumi.getter
    def managed(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        Managed or not.
        """
        return pulumi.get(self, "managed")

    @managed.setter
    def managed(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "managed", value)

    @_builtins.property
    @pulumi.getter(name="orgId")
    def org_id(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Org identifier.
        """
        return pulumi.get(self, "org_id")

    @org_id.setter
    def org_id(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "org_id", value)

    @_builtins.property
    @pulumi.getter
    def principals(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['RoleAssignmentsPrincipalArgs']]]]:
        """
        Principal.
        """
        return pulumi.get(self, "principals")

    @principals.setter
    def principals(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['RoleAssignmentsPrincipalArgs']]]]):
        pulumi.set(self, "principals", value)

    @_builtins.property
    @pulumi.getter(name="projectId")
    def project_id(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Project Identifier
        """
        return pulumi.get(self, "project_id")

    @project_id.setter
    def project_id(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "project_id", value)

    @_builtins.property
    @pulumi.getter(name="resourceGroupIdentifier")
    def resource_group_identifier(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Resource group identifier.
        """
        return pulumi.get(self, "resource_group_identifier")

    @resource_group_identifier.setter
    def resource_group_identifier(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "resource_group_identifier", value)

    @_builtins.property
    @pulumi.getter(name="roleIdentifier")
    def role_identifier(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Role identifier.
        """
        return pulumi.get(self, "role_identifier")

    @role_identifier.setter
    def role_identifier(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "role_identifier", value)


@pulumi.type_token("harness:platform/roleAssignments:RoleAssignments")
class RoleAssignments(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 disabled: Optional[pulumi.Input[_builtins.bool]] = None,
                 identifier: Optional[pulumi.Input[_builtins.str]] = None,
                 managed: Optional[pulumi.Input[_builtins.bool]] = None,
                 org_id: Optional[pulumi.Input[_builtins.str]] = None,
                 principals: Optional[pulumi.Input[Sequence[pulumi.Input[Union['RoleAssignmentsPrincipalArgs', 'RoleAssignmentsPrincipalArgsDict']]]]] = None,
                 project_id: Optional[pulumi.Input[_builtins.str]] = None,
                 resource_group_identifier: Optional[pulumi.Input[_builtins.str]] = None,
                 role_identifier: Optional[pulumi.Input[_builtins.str]] = None,
                 __props__=None):
        """
        Resource for creating role assignments in Harness.

        ## Import

        The `pulumi import` command can be used, for example:

        Import account level role assignments

        ```sh
        $ pulumi import harness:platform/roleAssignments:RoleAssignments example <role_assignments_id>
        ```

        Import org level role assignments

        ```sh
        $ pulumi import harness:platform/roleAssignments:RoleAssignments example <ord_id>/<role_assignments_id>
        ```

        Import project level role assignments

        ```sh
        $ pulumi import harness:platform/roleAssignments:RoleAssignments example <org_id>/<project_id>/<role_assignments_id>
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[_builtins.bool] disabled: Disabled or not.
        :param pulumi.Input[_builtins.str] identifier: Identifier for role assignment.
        :param pulumi.Input[_builtins.bool] managed: Managed or not.
        :param pulumi.Input[_builtins.str] org_id: Org identifier.
        :param pulumi.Input[Sequence[pulumi.Input[Union['RoleAssignmentsPrincipalArgs', 'RoleAssignmentsPrincipalArgsDict']]]] principals: Principal.
        :param pulumi.Input[_builtins.str] project_id: Project Identifier
        :param pulumi.Input[_builtins.str] resource_group_identifier: Resource group identifier.
        :param pulumi.Input[_builtins.str] role_identifier: Role identifier.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: RoleAssignmentsArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        Resource for creating role assignments in Harness.

        ## Import

        The `pulumi import` command can be used, for example:

        Import account level role assignments

        ```sh
        $ pulumi import harness:platform/roleAssignments:RoleAssignments example <role_assignments_id>
        ```

        Import org level role assignments

        ```sh
        $ pulumi import harness:platform/roleAssignments:RoleAssignments example <ord_id>/<role_assignments_id>
        ```

        Import project level role assignments

        ```sh
        $ pulumi import harness:platform/roleAssignments:RoleAssignments example <org_id>/<project_id>/<role_assignments_id>
        ```

        :param str resource_name: The name of the resource.
        :param RoleAssignmentsArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(RoleAssignmentsArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 disabled: Optional[pulumi.Input[_builtins.bool]] = None,
                 identifier: Optional[pulumi.Input[_builtins.str]] = None,
                 managed: Optional[pulumi.Input[_builtins.bool]] = None,
                 org_id: Optional[pulumi.Input[_builtins.str]] = None,
                 principals: Optional[pulumi.Input[Sequence[pulumi.Input[Union['RoleAssignmentsPrincipalArgs', 'RoleAssignmentsPrincipalArgsDict']]]]] = None,
                 project_id: Optional[pulumi.Input[_builtins.str]] = None,
                 resource_group_identifier: Optional[pulumi.Input[_builtins.str]] = None,
                 role_identifier: Optional[pulumi.Input[_builtins.str]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = RoleAssignmentsArgs.__new__(RoleAssignmentsArgs)

            __props__.__dict__["disabled"] = disabled
            __props__.__dict__["identifier"] = identifier
            __props__.__dict__["managed"] = managed
            __props__.__dict__["org_id"] = org_id
            if principals is None and not opts.urn:
                raise TypeError("Missing required property 'principals'")
            __props__.__dict__["principals"] = principals
            __props__.__dict__["project_id"] = project_id
            if resource_group_identifier is None and not opts.urn:
                raise TypeError("Missing required property 'resource_group_identifier'")
            __props__.__dict__["resource_group_identifier"] = resource_group_identifier
            if role_identifier is None and not opts.urn:
                raise TypeError("Missing required property 'role_identifier'")
            __props__.__dict__["role_identifier"] = role_identifier
        super(RoleAssignments, __self__).__init__(
            'harness:platform/roleAssignments:RoleAssignments',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            disabled: Optional[pulumi.Input[_builtins.bool]] = None,
            identifier: Optional[pulumi.Input[_builtins.str]] = None,
            managed: Optional[pulumi.Input[_builtins.bool]] = None,
            org_id: Optional[pulumi.Input[_builtins.str]] = None,
            principals: Optional[pulumi.Input[Sequence[pulumi.Input[Union['RoleAssignmentsPrincipalArgs', 'RoleAssignmentsPrincipalArgsDict']]]]] = None,
            project_id: Optional[pulumi.Input[_builtins.str]] = None,
            resource_group_identifier: Optional[pulumi.Input[_builtins.str]] = None,
            role_identifier: Optional[pulumi.Input[_builtins.str]] = None) -> 'RoleAssignments':
        """
        Get an existing RoleAssignments resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[_builtins.bool] disabled: Disabled or not.
        :param pulumi.Input[_builtins.str] identifier: Identifier for role assignment.
        :param pulumi.Input[_builtins.bool] managed: Managed or not.
        :param pulumi.Input[_builtins.str] org_id: Org identifier.
        :param pulumi.Input[Sequence[pulumi.Input[Union['RoleAssignmentsPrincipalArgs', 'RoleAssignmentsPrincipalArgsDict']]]] principals: Principal.
        :param pulumi.Input[_builtins.str] project_id: Project Identifier
        :param pulumi.Input[_builtins.str] resource_group_identifier: Resource group identifier.
        :param pulumi.Input[_builtins.str] role_identifier: Role identifier.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _RoleAssignmentsState.__new__(_RoleAssignmentsState)

        __props__.__dict__["disabled"] = disabled
        __props__.__dict__["identifier"] = identifier
        __props__.__dict__["managed"] = managed
        __props__.__dict__["org_id"] = org_id
        __props__.__dict__["principals"] = principals
        __props__.__dict__["project_id"] = project_id
        __props__.__dict__["resource_group_identifier"] = resource_group_identifier
        __props__.__dict__["role_identifier"] = role_identifier
        return RoleAssignments(resource_name, opts=opts, __props__=__props__)

    @_builtins.property
    @pulumi.getter
    def disabled(self) -> pulumi.Output[Optional[_builtins.bool]]:
        """
        Disabled or not.
        """
        return pulumi.get(self, "disabled")

    @_builtins.property
    @pulumi.getter
    def identifier(self) -> pulumi.Output[_builtins.str]:
        """
        Identifier for role assignment.
        """
        return pulumi.get(self, "identifier")

    @_builtins.property
    @pulumi.getter
    def managed(self) -> pulumi.Output[Optional[_builtins.bool]]:
        """
        Managed or not.
        """
        return pulumi.get(self, "managed")

    @_builtins.property
    @pulumi.getter(name="orgId")
    def org_id(self) -> pulumi.Output[Optional[_builtins.str]]:
        """
        Org identifier.
        """
        return pulumi.get(self, "org_id")

    @_builtins.property
    @pulumi.getter
    def principals(self) -> pulumi.Output[Sequence['outputs.RoleAssignmentsPrincipal']]:
        """
        Principal.
        """
        return pulumi.get(self, "principals")

    @_builtins.property
    @pulumi.getter(name="projectId")
    def project_id(self) -> pulumi.Output[Optional[_builtins.str]]:
        """
        Project Identifier
        """
        return pulumi.get(self, "project_id")

    @_builtins.property
    @pulumi.getter(name="resourceGroupIdentifier")
    def resource_group_identifier(self) -> pulumi.Output[_builtins.str]:
        """
        Resource group identifier.
        """
        return pulumi.get(self, "resource_group_identifier")

    @_builtins.property
    @pulumi.getter(name="roleIdentifier")
    def role_identifier(self) -> pulumi.Output[_builtins.str]:
        """
        Role identifier.
        """
        return pulumi.get(self, "role_identifier")

